RoutedNodeCliProvider class final

Registers CLI commands owned by the routed_node runtime package.

Constructors

RoutedNodeCliProvider()
Creates the routed_node CLI provider.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

boot(Container container) Future<void>
Runs after all providers have registered their bindings.
inherited
cleanup(Container container) Future<void>
Releases resources owned by this provider.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(Container container) → void
Registers bindings, instances, and aliases with container.
registerCliCommands(dynamic registry) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited