CloudflareCache class abstract interface

The Cache API for a Cloudflare edge cache namespace.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(CloudflareRequest request, {bool ignoreMethod = false}) Future<bool>
Removes a cached response and reports whether an entry was removed.
match(CloudflareRequest request, {bool ignoreMethod = false}) Future<CloudflareResponse?>
Finds a cached response for request.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
put(CloudflareRequest request, CloudflareResponse response) Future<void>
Stores response under request. The request must be a GET request.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited