delete abstract method
Removes a cached response and reports whether an entry was removed.
Implementation
Future<bool> delete(CloudflareRequest request, {bool ignoreMethod = false});
Removes a cached response and reports whether an entry was removed.
Future<bool> delete(CloudflareRequest request, {bool ignoreMethod = false});