CloudflareContainer class abstract interface

Low-level Container controls exposed by a Container-backed Durable Object.

Properties

hashCode int
The hash code for this object.
no setterinherited
running bool
The running value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

destroy([String? error]) Future<void>
Performs the destroy operation.
exec(Iterable<String> command, {CloudflareContainerExecOptions? options}) Future<CloudflareContainerProcess>
Performs the exec operation.
getTcpPort(int port) CloudflareContainerTcpPort
Performs the getTcpPort operation.
monitor() Future<void>
Performs the monitor operation.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
signal(int signal) → void
Performs the signal operation.
start({CloudflareContainerStartOptions? options}) → void
Performs the start operation.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited