CloudflareContainerExecOptions class final

Options used when executing a command in a running Container.

Constructors

CloudflareContainerExecOptions({CloudflareContainerStreamMode stdout = CloudflareContainerStreamMode.pipe, CloudflareContainerStreamMode stderr = CloudflareContainerStreamMode.pipe, Map<String, String> environment = const <String, String>{}, String? cwd, String? user})
Creates a CloudflareContainerExecOptions value.
const

Properties

cwd String?
The cwd value.
final
environment Map<String, String>
The environment value.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stderr CloudflareContainerStreamMode
The stderr value.
final
stdout CloudflareContainerStreamMode
The stdout value.
final
user String?
The user value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited