CloudflareContainerProcess class abstract interface

A process started inside a Cloudflare Container.

Properties

exitCode Future<int>
The exitCode value.
no setter
hashCode int
The hash code for this object.
no setterinherited
pid int
The pid value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

kill([int? signal]) → void
Sends a signal to the process.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
output() Future<CloudflareContainerExecOutput>
Reads the captured output once and waits for the process to exit.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited