CloudflareContainerStartOptions class final

Options used when starting a Container process.

Constructors

CloudflareContainerStartOptions({Map<String, String> environment = const <String, String>{}, List<String> entrypoint = const <String>[], bool? enableInternet})
Creates a CloudflareContainerStartOptions value.
const

Properties

enableInternet bool?
The enableInternet value.
final
entrypoint List<String>
The entrypoint value.
final
environment Map<String, String>
The environment value.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited