CloudflareDurableObject class abstract

A Durable Object implementation constructed for a Worker request.

Implementers

Constructors

CloudflareDurableObject(CloudflareDurableObjectState state, CloudflareEnvironment env)
Creates a CloudflareDurableObject value.
const

Properties

env CloudflareEnvironment
The env value.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state CloudflareDurableObjectState
The state value.
final

Methods

alarm() FutureOr<void>
Performs the alarm operation.
fetch(CloudflareRequest request) FutureOr<CloudflareResponse>
Performs the fetch operation.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
webSocketClose(CloudflareWebSocket webSocket, int code, String reason, bool wasClean) FutureOr<void>
Handles a WebSocket closed by the peer or by the Worker runtime.
webSocketError(CloudflareWebSocket webSocket, Object error) FutureOr<void>
Handles a WebSocket error reported by the Worker runtime.
webSocketMessage(CloudflareWebSocket webSocket, Object message) FutureOr<void>
Handles a message delivered by the Durable Object hibernation API.

Operators

operator ==(Object other) bool
The equality operator.
inherited