CloudflareDurableObjectNamespace class abstract interface

A Durable Object namespace binding.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(CloudflareDurableObjectId id, {String? locationHint}) CloudflareDurableObjectStub
Performs the get operation.
getByName(String name, {String? locationHint}) CloudflareDurableObjectStub
Performs the getByName operation.
idFromName(String name) CloudflareDurableObjectId
Performs the idFromName operation.
idFromString(String id) CloudflareDurableObjectId
Performs the idFromString operation.
newUniqueId({String? jurisdiction}) CloudflareDurableObjectId
Performs the newUniqueId operation.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited