CloudflareDurableObjectSqlResult class abstract interface

A SQLite statement result. Methods mirror the current Workers SQL API.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
one() Map<String, Object?>
Performs the one operation.
raw() List<Object?>
Performs the raw operation.
run() → void
Performs the run operation.
toArray() List<Map<String, Object?>>
Performs the toArray operation.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited