CloudflareDurableObjectStub class abstract interface

A Durable Object request stub.

Properties

hashCode int
The hash code for this object.
no setterinherited
id CloudflareDurableObjectId
The id value.
no setter
name String?
The name value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

fetch(CloudflareRequest request) Future<CloudflareResponse>
Sends a Fetch request to the object.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited