fetch abstract method
Sends a Fetch request to the object.
The native Worker request and response are converted by routed_node.
Implementation
Future<CloudflareResponse> fetch(CloudflareRequest request);
Sends a Fetch request to the object.
The native Worker request and response are converted by routed_node.
Future<CloudflareResponse> fetch(CloudflareRequest request);