A Cloudflare Worker environment binding set.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
binding(
String name) → Object -
Returns the unwrapped binding with
name. -
container(
String name) → CloudflareContainerBinding -
Returns the Container binding identified by
name. -
d1(
String name) → CloudflareD1Database - Returns a D1 database binding.
-
durableObjectNamespace(
String name) → CloudflareDurableObjectNamespace - Returns a Durable Object namespace binding.
-
kv(
String name) → CloudflareKvNamespace - Returns a KV namespace binding.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queue(
String name) → CloudflareQueue - Returns a Queue producer binding.
-
r2(
String name) → CloudflareR2Bucket - Returns an R2 bucket binding.
-
secretsStore(
String name) → CloudflareSecretsStoreBinding - Returns an account-level Secrets Store binding.
-
service(
String name) → CloudflareServiceBinding - Returns a Worker-to-Worker service binding.
-
toString(
) → String -
A string representation of this object.
inherited
-
worker(
String name) → CloudflareServiceBinding - Returns a Worker-to-Worker service binding using the platform term.
-
workflow(
String name) → CloudflareWorkflow - Returns a Workflow binding.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited