The request execution context supplied by a Cloudflare Worker.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
passThroughOnException(
) → void - Requests that the platform pass through uncaught exceptions.
-
toString(
) → String -
A string representation of this object.
inherited
-
waitUntil(
Future< void> future) → void - Keeps asynchronous work alive after the response is returned.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited