CloudflareKvNamespace class abstract interface

A Cloudflare KV namespace binding.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(Iterable<String> keys) Future<void>
Performs the delete operation.
get(String key, {int? cacheTtl}) Future<String?>
Performs the get operation.
getBytes(String key, {int? cacheTtl}) Future<Uint8List?>
Performs the getBytes operation.
getJson<T>(String key, {int? cacheTtl}) Future<T?>
Provides the declared Cloudflare API member.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
put(String key, Object value, {DateTime? expiration, int? expirationTtl, Object? metadata}) Future<void>
Performs the put operation.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited