CloudflareQueue class abstract interface

A Cloudflare Queue producer binding.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

metrics() Future<CloudflareQueueMetrics>
Performs the metrics operation.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send(Object? body, {CloudflareQueueContentType? contentType, int? delaySeconds}) Future<CloudflareQueueSendResult>
Performs the send operation.
sendBatch(Iterable<CloudflareQueueMessage> messages, {int? delaySeconds}) Future<CloudflareQueueSendResult>
Performs the sendBatch operation.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited