CloudflareQueueBatch class final

A batch delivered to a Cloudflare Queue consumer Worker.

Constructors

CloudflareQueueBatch({required String queue, required Iterable<CloudflareQueueDelivery> messages, required void acknowledgeAll(), required void retryAllHandler(Duration? delay)})
Creates a queue batch value.

Properties

hashCode int
The hash code for this object.
no setterinherited
messages List<CloudflareQueueDelivery>
Messages delivered in this batch.
final
queue String
Name of the queue that produced this batch.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

ackAll() → void
Acknowledges every message that has not already been explicitly handled.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
retryAll({Duration? delay}) → void
Requests a later delivery for every message not explicitly handled.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited