CloudflareQueueContentType enum

The serialization format used for a queued message body.

Inheritance
Available extensions

Values

text → const CloudflareQueueContentType

A UTF-8 text message.

bytes → const CloudflareQueueContentType

A byte sequence.

json → const CloudflareQueueContentType

A JSON-encoded message.

v8 → const CloudflareQueueContentType

A V8-serialized value.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CloudflareQueueContentType>
A constant List of the values in this enum, in order of their declaration.