CloudflareQueueMessage class final

Configuration or result data used by the Cloudflare API.

Constructors

CloudflareQueueMessage(Object? body, {CloudflareQueueContentType? contentType, int? delaySeconds})
Creates a CloudflareQueueMessage value.
const

Properties

body Object?
The body value.
final
contentType CloudflareQueueContentType?
The contentType value.
final
delaySeconds int?
The delaySeconds value.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited