CloudflareQueueMetrics class final

Configuration or result data used by the Cloudflare API.

Constructors

CloudflareQueueMetrics({int? backlogCount, int? backlogBytes, DateTime? oldestMessageTimestamp})
Creates a CloudflareQueueMetrics value.
const

Properties

backlogBytes int?
The backlogBytes value.
final
backlogCount int?
The backlogCount value.
final
hashCode int
The hash code for this object.
no setterinherited
oldestMessageTimestamp DateTime?
The oldestMessageTimestamp value.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited