CloudflareQueueSendResult class final

Configuration or result data used by the Cloudflare API.

Constructors

CloudflareQueueSendResult({CloudflareQueueMetrics? metrics})
Creates a CloudflareQueueSendResult value.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
metrics CloudflareQueueMetrics?
The metrics value.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited