CloudflareR2Bucket class abstract interface

An R2 object-storage bucket binding.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(Object keys) Future<void>
Deletes one key or an iterable of keys.
get(String key) Future<CloudflareR2Object?>
Performs the get operation.
Performs the head operation.
list({CloudflareR2ListOptions? options}) Future<CloudflareR2ListResult>
Performs the list operation.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
put(String key, Object? value, {CloudflareR2PutOptions? options}) Future<CloudflareR2Object?>
Performs the put operation.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited