throwOnError property
Whether operation failures are rethrown instead of converted to the
fallback values used by storage_fs.
Implementation
final bool throwOnError;
Whether operation failures are rethrown instead of converted to the
fallback values used by storage_fs.
final bool throwOnError;