CloudflareR2ListResult class final
Configuration or result data used by the Cloudflare API.
Constructors
-
CloudflareR2ListResult({required List<
CloudflareR2Object> objects, required bool truncated, String? cursor, List<String> delimitedPrefixes = const <String>[]}) -
Creates a CloudflareR2ListResult value.
const
Properties
- cursor → String?
-
The cursor value.
final
-
delimitedPrefixes
→ List<
String> -
The delimitedPrefixes value.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
objects
→ List<
CloudflareR2Object> -
The objects value.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- truncated → bool
-
The truncated value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited