completedTtl property
How long completed occurrences remain deduplicated.
A zero duration asks the backend to retain the key indefinitely.
Implementation
final Duration completedTtl;
How long completed occurrences remain deduplicated.
A zero duration asks the backend to retain the key indefinitely.
final Duration completedTtl;