get abstract method

Future<String?> get()

Reads the secret value. The value is never available through the management API; it is only returned by the bound Worker runtime.

Implementation

Future<String?> get();