CloudflareServiceBinding class abstract interface

A Worker-to-Worker service binding.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call<T>(String method, [Iterable<Object?> arguments = const [], CloudflareJsonDecoder<T>? decode]) Future<T?>
Calls an RPC method exposed by the bound Worker.
fetch(CloudflareRequest request) Future<CloudflareResponse>
Performs the fetch operation.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited