The client/server WebSocket pair used to create a Fetch upgrade response.
Properties
- client → CloudflareWebSocket
-
The client value.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- response → CloudflareResponse
-
The response value.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- server → CloudflareWebSocket
-
The server value.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited