CloudflareWorkflow class abstract interface

A Cloudflare Workflow binding.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create({CloudflareWorkflowCreateOptions? options}) Future<CloudflareWorkflowInstance>
Performs the create operation.
createBatch(Iterable<CloudflareWorkflowCreateOptions> options) Future<List<CloudflareWorkflowInstance>>
Performs the createBatch operation.
get(String id) Future<CloudflareWorkflowInstance>
Performs the get operation.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited