CloudflareWorkflowCreateOptions class final

Options for creating a Workflow instance.

Constructors

CloudflareWorkflowCreateOptions({String? id, Object? params, Object? successRetention, Object? errorRetention})
Creates a CloudflareWorkflowCreateOptions value.
const

Properties

errorRetention Object?
The errorRetention value.
final
hashCode int
The hash code for this object.
no setterinherited
id String?
The id value.
final
params Object?
The params value.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
successRetention Object?
The successRetention value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited