CloudflareWorkflowInstance class abstract interface

A running Workflow instance.

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
The id value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause() Future<void>
Performs the pause operation.
restart({CloudflareWorkflowRestartOptions? options}) Future<void>
Performs the restart operation.
resume() Future<void>
Performs the resume operation.
sendEvent({required String type, Object? payload}) Future<void>
Performs the sendEvent operation.
status() Future<CloudflareWorkflowStatus>
Performs the status operation.
terminate({CloudflareWorkflowTerminateOptions? options}) Future<void>
Performs the terminate operation.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited