CloudflareWorkflowStatus class final

The current status of a Workflow instance.

Constructors

CloudflareWorkflowStatus({required String status, CloudflareWorkflowError? error, Object? output, CloudflareWorkflowRollback? rollback})
Creates a CloudflareWorkflowStatus value.
const

Properties

error CloudflareWorkflowError?
The error value.
final
hashCode int
The hash code for this object.
no setterinherited
output Object?
The output value.
final
rollback CloudflareWorkflowRollback?
The rollback value.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
The status value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited