CloudflareWorkflowStepReference class final

Identifies a Workflow step when restarting an instance.

Constructors

CloudflareWorkflowStepReference({required String name, int? count, String? type})
Creates a CloudflareWorkflowStepReference value.
const

Properties

count int?
The count value.
final
hashCode int
The hash code for this object.
no setterinherited
name String
The name value.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
The type value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited