defineCloudflareFetchFactoryAsync function

void defineCloudflareFetchFactoryAsync(
  1. Future<Engine> factory()
)

Installs a Cloudflare Fetch entry whose engine is initialized lazily per Worker isolate, on the first request.

Implementation

void defineCloudflareFetchFactoryAsync(Future<Engine> Function() factory) {
  defineFetchExportFactoryAsync(
    'Cloudflare',
    factory,
    capabilities: cloudflareCapabilities,
  );
}