keepNodeEventLoopAlive function
VM / non-JS stub: real Node bind requires compiling this package for a
JavaScript runtime (dart compile js / dart2wasm with Node host).
Implementation
void keepNodeEventLoopAlive({bool persistent = true}) {}
VM / non-JS stub: real Node bind requires compiling this package for a
JavaScript runtime (dart compile js / dart2wasm with Node host).
void keepNodeEventLoopAlive({bool persistent = true}) {}