RoutedNodeContext class final

Runtime-scoped host context carried through a Routed request.

Constructors

RoutedNodeContext({required RoutedNodeRuntimeInfo info, RoutedNodeExtension? extension})
Creates request-scoped runtime metadata and an optional extension.
const

Properties

extension RoutedNodeExtension?
The optional host-specific handles for the current request.
final
hashCode int
The hash code for this object.
no setterinherited
info RoutedNodeRuntimeInfo
The runtime and capabilities for the current host invocation.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

extensionAs<T extends RoutedNodeExtension>() → T?
Returns the host extension when it has type T.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited