RoutedNodeLifecycleEvent class final

Host lifecycle event published through Routed's existing EventManager.

Constructors

RoutedNodeLifecycleEvent({required RoutedNodeLifecyclePhase phase, required RoutedNodeRuntimeInfo info, String? requestId, Object? error, StackTrace? stackTrace})
Creates a lifecycle event for a host adapter transition.

Properties

error Object?
The failure associated with the event, when phase is requestFailed.
final
hashCode int
The hash code for this object.
no setterinherited
info RoutedNodeRuntimeInfo
Runtime metadata for the host that emitted the event.
final
phase RoutedNodeLifecyclePhase
The lifecycle phase represented by this event.
final
requestId String?
The host request identifier, when one is available.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
The stack trace associated with error, when available.
final
timestamp DateTime
The timestamp when the event was created.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited