VercelRequestProperties class final

Vercel request metadata exposed by the platform's x-vercel-* headers.

This is the Routed equivalent of Dart Edge's request.vc properties. The values are optional because they are not present for every request or local development environment.

Constructors

VercelRequestProperties(Request request)
Creates a VercelRequestProperties value.
const

Properties

city String?
Client city reported by Vercel, when available.
no setter
country String?
Client country code reported by Vercel, when available.
no setter
countryRegion String?
Client country or state region reported by Vercel.
no setter
hashCode int
The hash code for this object.
no setterinherited
ipAddress String?
Client IP address reported by Vercel, when available.
no setter
latitude String?
Client latitude reported by Vercel, when available.
no setter
longitude String?
Client longitude reported by Vercel, when available.
no setter
region String?
Vercel region inferred from the request identifier.
no setter
request → Request
Provides the declared host integration API member.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited