CloudflareContainerExecOutput class final
Buffered output returned by a Container process.
Constructors
- CloudflareContainerExecOutput({required Uint8List stdout, required Uint8List stderr, required int exitCode})
-
Creates a CloudflareContainerExecOutput value.
const
Properties
- exitCode → int
-
The exitCode value.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stderr → Uint8List
-
The stderr value.
final
- stderrText → String
-
The stderrText value.
no setter
- stdout → Uint8List
-
The stdout value.
final
- stdoutText → String
-
The stdoutText value.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited