State available to a Durable Object instance.
Properties
- container → CloudflareContainer?
-
Low-level Container controls when this Durable Object owns a Container.
Ordinary Durable Objects return
null.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- id → CloudflareDurableObjectId
-
The id value.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storage → CloudflareDurableObjectStorage
-
The storage value.
no setter
Methods
-
abort(
[String? reason]) → void - Performs the abort operation.
-
acceptWebSocket(
CloudflareWebSocket webSocket, {Iterable< String> tags = const []}) → void - Accepts a WebSocket using the Durable Object hibernation API.
-
blockConcurrencyWhile<
T> (Future< T> callback()) → Future<T> - Provides the declared Cloudflare API member.
-
getTags(
CloudflareWebSocket webSocket) → List< String> -
Returns the tags attached to
webSocket. -
getWebSockets(
{String? tag}) → List< CloudflareWebSocket> -
Returns hibernating WebSockets, optionally filtered by
tag. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
waitUntil(
Future< void> future) → void - Performs the waitUntil operation.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited