Legacy and SQLite-backed Durable Object storage.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sql → CloudflareDurableObjectSqlStorage?
-
Returns the SQLite storage API when this object is backed by SQLite.
no setter
Methods
-
delete(
String key, {bool? allowConcurrency, bool? allowUnconfirmed, bool? noCache}) → Future< bool> - Performs the delete operation.
-
deleteAlarm(
{bool? allowConcurrency, bool? allowUnconfirmed}) → Future< void> - Performs the deleteAlarm operation.
-
deleteAll(
{bool? allowConcurrency, bool? allowUnconfirmed, bool? noCache}) → Future< void> - Performs the deleteAll operation.
-
deleteEntries(
Iterable< String> keys, {bool? allowConcurrency, bool? allowUnconfirmed, bool? noCache}) → Future<bool> - Performs the deleteEntries operation.
-
get<
T> (String key, {bool? allowConcurrency, bool? noCache}) → Future< T?> - Provides the declared Cloudflare API member.
-
getAlarm(
{bool? allowConcurrency}) → Future< int?> - Performs the getAlarm operation.
-
getEntries<
T> (Iterable< String> keys, {bool? allowConcurrency, bool? noCache}) → Future<Map< String, T> > - Provides the declared Cloudflare API member.
-
list<
T> ({String? start, String? startAfter, String? end, String? prefix, bool? reverse, int? limit, bool? allowConcurrency, bool? noCache}) → Future< Map< String, T> > - Provides the declared Cloudflare API member.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
put<
T> (String key, T value, {bool? allowConcurrency, bool? allowUnconfirmed, bool? noCache}) → Future< void> - Provides the declared Cloudflare API member.
-
putEntries<
T> (Map< String, T> entries, {bool? allowConcurrency, bool? allowUnconfirmed, bool? noCache}) → Future<void> - Provides the declared Cloudflare API member.
-
setAlarm(
DateTime scheduledTime, {bool? allowConcurrency, bool? allowUnconfirmed}) → Future< void> - Performs the setAlarm operation.
-
sync(
) → Future< void> - Performs the sync operation.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited