CloudflareR2ListOptions class final
Configuration or result data used by the Cloudflare API.
Constructors
Properties
- cursor → String?
-
The cursor value.
final
- delimiter → String?
-
The delimiter value.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
include
→ List<
String> ? -
The include value.
final
- limit → int?
-
The limit value.
final
- prefix → String?
-
The prefix value.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited