CloudflareR2Object class final
Metadata and body returned by an R2 bucket operation.
Constructors
-
CloudflareR2Object({required String key, String? version, int? size, String? etag, String? httpEtag, DateTime? uploaded, Map<
String, String> httpMetadata = const <String, String>{}, Map<String, String> customMetadata = const <String, String>{}, Map<String, String> checksums = const <String, String>{}, Stream<List< ? body})int> > -
Creates a CloudflareR2Object value.
const
Properties
-
body
→ Stream<
List< ?int> > -
The body value.
final
-
checksums
→ Map<
String, String> -
The checksums value.
final
-
customMetadata
→ Map<
String, String> -
The customMetadata value.
final
- etag → String?
-
The etag value.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- httpEtag → String?
-
The httpEtag value.
final
-
httpMetadata
→ Map<
String, String> -
The httpMetadata value.
final
- key → String
-
The key value.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → int?
-
The size value.
final
- uploaded → DateTime?
-
The uploaded value.
final
- version → String?
-
The version value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
readAsBytes(
) → Future< Uint8List> - Reads the object body into memory.
-
readAsString(
) → Future< String> - Reads the object body as UTF-8 text.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited