A Fetch request represented without exposing the host's JavaScript types.
Properties
-
cf
→ Map<
String, Object?> -
Cloudflare edge metadata attached to an incoming Worker request.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, String> -
The headers value.
no setter
- method → String
-
The method value.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url → String
-
The url value.
no setter
Methods
-
json<
T> ({CloudflareJsonDecoder< T> ? decode}) → Future<T?> - Provides the declared Cloudflare API member.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
text(
) → Future< String> - Performs the text operation.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited