cf property
Cloudflare edge metadata attached to an incoming Worker request.
This is empty for requests constructed with createCloudflareRequest.
Values are intentionally represented as Dart primitives and collections
because the available keys vary by plan and Cloudflare feature set.
Implementation
Map<String, Object?> get cf;