CloudflareScheduledEvent class final
A Cloudflare Cron Trigger invocation.
Constructors
- CloudflareScheduledEvent({required DateTime scheduledTime, required String? cron, required void noRetryHandler()})
-
Creates a scheduled event value.
const
Properties
- cron → String?
-
Cron expression that triggered this invocation, when available.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scheduledTime → DateTime
-
Scheduled invocation time in UTC.
final
Methods
-
noRetry(
) → void - Prevents Cloudflare from retrying a failed scheduled invocation.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited