CloudflareWorkflowRollback class final
Rollback state returned as part of Workflow instance status.
Constructors
- CloudflareWorkflowRollback({required String outcome, CloudflareWorkflowError? error})
-
Creates a CloudflareWorkflowRollback value.
const
Properties
- error → CloudflareWorkflowError?
-
The error value.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- outcome → String
-
The outcome value.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited