NodeRoutedWebSocket class final
WebSocket implementation for a raw Node upgrade socket.
Constructors
-
NodeRoutedWebSocket({required NodeWebSocketSocketView socket, List<
int> head = const []}) - Starts decoding WebSocket frames from a Node upgrade socket.
Properties
- closeCode → int?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- socket → NodeWebSocketSocketView
-
Raw Node socket carrying the WebSocket frames.
final
-
stream
→ Stream<
Object?> -
no setter
Methods
-
add(
Object? data) → void -
close(
[int? code, String? reason]) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited