NodeWebSocketUpgradeResponse class final
Native handshake information for a Node upgrade.
Constructors
- NodeWebSocketUpgradeResponse({required NodeWebSocketSocketView socket, required String key, String? protocol})
-
Creates a NodeWebSocketUpgradeResponse value.
const
Properties
- acceptKey → String
-
Base64-encoded
Sec-WebSocket-Accepthandshake value.no setter -
handshake
→ List<
int> -
Raw HTTP 101 handshake bytes for the upgraded connection.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String
-
Client handshake key used to derive acceptKey.
final
- protocol → String?
-
Negotiated subprotocol, when one was selected.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- socket → NodeWebSocketSocketView
-
Upgraded Node socket that will carry the WebSocket frames.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited