RoutedNodeCapabilities class final
Capabilities declared by one host invocation.
Constructors
- RoutedNodeCapabilities({required RoutedNodeRuntime runtime, required RoutedNodeEntryModel entryModel, required bool streaming, required bool bufferedResponses, required bool webSocket, required bool fileSystem, required bool backgroundWork})
-
Describes the features available from a host adapter.
const
Properties
- backgroundWork → bool
-
Whether the host supports work that continues after a response.
final
- bufferedResponses → bool
-
Whether the adapter supports the buffered portable response path.
final
- entryModel → RoutedNodeEntryModel
-
Whether the host owns a listener or invokes a Fetch export.
final
- fileSystem → bool
-
Whether application code can use a host filesystem through this entrypoint.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtime → RoutedNodeRuntime
-
The runtime family that owns the current request.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- streaming → bool
-
Whether the adapter can stream response bodies.
final
- webSocket → bool
-
Whether the host can accept WebSocket upgrades.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited